@@ -39,11 +39,7 @@ class Kin8nmData:
             train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
         else:
             train, val = table, []
-        self.data = {
-            'train': train,
-            'val': val,
-            'all': np.concatenate((train, val))
-        }
+        self.data = {'train': train, 'val': val}
 
 
 if __name__ == '__main__':
